@@ -5,25 +5,14 @@
 #' impact of a variable on a self-defined measure, like the Gini Index.
 #' @keywords internal
 
-ex_f <- function(pred_params, ex_fun, samples) {
-
-  # Obtain the function from the string
-  fun <- get(ex_fun, envir = .GlobalEnv)
+ex_f <- function(pred_params, unquotedfun) {
 
   # Stop if not function
-  if (class(fun) != "function")
+  if (class(unquotedfun) != "function")
     stop("Argument 'ex-fun' has to be a function!")
 
-  # Get values
-  if (!samples)
-    vals <- fun(pred_params)
-  if (samples)
-    vals <- lapply(pred_params, FUN = function(listparts) {
-      apply(listparts, 1, FUN = function(x) {
-        x <- as.list(x)
-        return(fun(x))
-      })
-    })
+  # Try out whether function works
+  vals <- unquotedfun(pred_params)
 
   # Return values
   return(vals)
